# - Config file for the Dakota package
# It defines the following variables
#  Dakota_INCLUDE_DIRS - include directories for Dakota
#  Dakota_LIBRARIES    - libraries to link against
#  Dakota_EXECUTABLE   - the dakota executable

# Compute paths
get_filename_component(DAKOTA_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

# Our library dependencies (contains definitions for IMPORTED targets)
include("${DAKOTA_CMAKE_DIR}/DakotaTargets.cmake")


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach(comp)
endmacro()

####################################################################################

# Build tree option not yet working
if (Dakota_BUILD_TREE)
  # Dakota's build tree doesn't have a single convenient place for headers
  set(Dakota_INCLUDE_DIRS_TMP "/home/mpiper/build/dakota-6.4.0.src/_build;/home/mpiper/build/dakota-6.4.0.src/_build/generated;/home/mpiper/build/dakota-6.4.0.src/_build/src;/home/mpiper/build/dakota-6.4.0.src/src;/home/mpiper/build/dakota-6.4.0.src/packages;/home/mpiper/build/dakota-6.4.0.src/_build/packages/teuchos;/home/mpiper/build/dakota-6.4.0.src/_build/packages/teuchos/.;/home/mpiper/build/dakota-6.4.0.src/_build/packages/teuchos/packages/teuchos/src;/home/mpiper/build/dakota-6.4.0.src/packages/teuchos/packages/teuchos/src;/home/mpiper/build/dakota-6.4.0.src/_build/packages/pecos;/home/mpiper/build/dakota-6.4.0.src/packages/pecos/src;/home/mpiper/build/dakota-6.4.0.src/packages/VPISparseGrid/src;/home/mpiper/build/dakota-6.4.0.src/_build/packages/surfpack;/home/mpiper/build/dakota-6.4.0.src/packages/surfpack/src;/home/mpiper/build/dakota-6.4.0.src/_build/packages/acro/packages;/home/mpiper/build/dakota-6.4.0.src/_build/packages/acro/packages/utilib;/home/mpiper/build/dakota-6.4.0.src/packages/acro/packages/interfaces/src;/home/mpiper/build/dakota-6.4.0.src/packages/acro/packages/scolib/src;/home/mpiper/build/dakota-6.4.0.src/packages/acro/packages/utilib/src;/home/mpiper/build/dakota-6.4.0.src/packages/acro/packages/colin/src;/home/mpiper/build/dakota-6.4.0.src/packages/acro/packages/pebbl/src/bb;/home/mpiper/build/dakota-6.4.0.src/packages/acro/packages/pebbl/src/comm;/home/mpiper/build/dakota-6.4.0.src/packages/acro/packages/pebbl/src/misc;/home/mpiper/build/dakota-6.4.0.src/packages/acro/packages/pebbl/src/pbb;/home/mpiper/build/dakota-6.4.0.src/packages/acro/packages/pebbl/src/sched;/home/mpiper/build/dakota-6.4.0.src/packages/acro/tpl/tinyxml;/home/mpiper/build/dakota-6.4.0.src/_build/packages/DDACE;/home/mpiper/build/dakota-6.4.0.src/packages/DDACE/include;/home/mpiper/build/dakota-6.4.0.src/packages/dream;/home/mpiper/build/dakota-6.4.0.src/_build/packages/FSUDace;/home/mpiper/build/dakota-6.4.0.src/packages/FSUDace;/home/mpiper/build/dakota-6.4.0.src/_build/packages/hopspack/src/src-shared;/home/mpiper/build/dakota-6.4.0.src/packages/hopspack/src/src-shared;/home/mpiper/build/dakota-6.4.0.src/packages/hopspack/src/src-citizens;/home/mpiper/build/dakota-6.4.0.src/packages/hopspack/src/src-evaluator;/home/mpiper/build/dakota-6.4.0.src/packages/hopspack/src/src-executor;/home/mpiper/build/dakota-6.4.0.src/packages/hopspack/src/src-framework;/home/mpiper/build/dakota-6.4.0.src/packages/hopspack/src/src-main;/home/mpiper/build/dakota-6.4.0.src/_build/packages/JEGA;/home/mpiper/build/dakota-6.4.0.src/_build/packages/JEGA/eddy;/home/mpiper/build/dakota-6.4.0.src/packages/JEGA/eddy;/home/mpiper/build/dakota-6.4.0.src/packages/JEGA/include;/home/mpiper/build/dakota-6.4.0.src/_build/packages/NOMAD/src;/home/mpiper/build/dakota-6.4.0.src/packages/NOMAD/src;/home/mpiper/build/dakota-6.4.0.src/_build/packages/OPTPP/include;/home/mpiper/build/dakota-6.4.0.src/packages/OPTPP/include;/home/mpiper/build/dakota-6.4.0.src/packages/PSUADE;/home/mpiper/build/dakota-6.4.0.src/_build/packages/ampl")
  # This won't work yet.  Since Dakota is in a build tree the
  # libraries are scattered, but the import doesn't know where they
  # are.
  set(Dakota_LIBRARY_DIRS_TMP "/home/mpiper/build/dakota-6.4.0.src/_build/packages/teuchos/packages/teuchos/src")
else()
  set_and_check(Dakota_INCLUDE_DIRS_TMP "${PACKAGE_PREFIX_DIR}/include")
  set_and_check(Dakota_LIB_DIRS_TMP "${PACKAGE_PREFIX_DIR}/lib")
endif()

# Variables intended for use by other projects

set_and_check(Dakota_DIR ${DAKOTA_CMAKE_DIR})

# TODO: reference in src vs bin
set(Dakota_EXECUTABLE dakota)


set(Dakota_DEFINES "HAVE_CONFIG_H;BOOST_SIGNALS_NO_DEPRECATION_WARNING;HAVE_CONFIG_H;DISABLE_DAKOTA_CONFIG_H;BOOST_DISABLE_ASSERTS;HAVE_UNISTD_H;HAVE_SYSTEM;HAVE_WORKING_FORK;HAVE_WORKING_VFORK;HAVE_SYS_WAIT_H;HAVE_USLEEP;DAKOTA_F90;HAVE_PECOS;HAVE_SURFPACK;DAKOTA_COLINY;DAKOTA_UTILIB;HAVE_ADAPTIVE_SAMPLING;HAVE_CONMIN;HAVE_DDACE;HAVE_DREAM;HAVE_FSUDACE;DAKOTA_HOPS;HAVE_JEGA;HAVE_NCSU;HAVE_NL2SOL;HAVE_NOMAD;HAVE_OPTPP;DAKOTA_OPTPP;HAVE_PSUADE;HAVE_AMPL")

set(Dakota_INCLUDE_DIRS ${Dakota_INCLUDE_DIRS_TMP})

set(Dakota_LIBRARY_DIRS ${Dakota_LIB_DIRS_TMP})

# These are IMPORTED targets created by DakotaTargets.cmake
set(Dakota_LIBRARIES "dakota_src;dakota_src_fortran;nidr;teuchos;pecos;pecos_src;lhs;lhs_mods;lhs_mod;dfftpack;sparsegrid;surfpack;surfpack;surfpack_fortran;utilib;colin;interfaces;scolib;3po;pebbl;tinyxml;conmin;ddace;dream;fsudace;hopspack;jega;jega_fe;moga;soga;eutils;utilities;ncsuopt;cport;nomad;optpp;psuade;amplsolver")

# Not built in Dakota's CMake process
set(Dakota_EXTPROJ_LIBRARIES "")

# TPLs external to the build
set(Dakota_TPL_INCLUDE_DIRS "/home/mpiper/dakota-6.4.0.Linux-Ubuntu.x86_64/include;/home/mpiper/dakota-6.4.0.Linux-Ubuntu.x86_64/include")

set(Dakota_TPL_LIBRARY_DIRS "/home/mpiper/dakota-6.4.0.Linux-Ubuntu.x86_64/lib")

set(Dakota_TPL_LIBRARIES "/home/mpiper/dakota-6.4.0.Linux-Ubuntu.x86_64/lib/libboost_filesystem.so;/home/mpiper/dakota-6.4.0.Linux-Ubuntu.x86_64/lib/libboost_program_options.so;/home/mpiper/dakota-6.4.0.Linux-Ubuntu.x86_64/lib/libboost_regex.so;/home/mpiper/dakota-6.4.0.Linux-Ubuntu.x86_64/lib/libboost_serialization.so;/home/mpiper/dakota-6.4.0.Linux-Ubuntu.x86_64/lib/libboost_system.so;/home/mpiper/dakota-6.4.0.Linux-Ubuntu.x86_64/lib/libboost_signals.so;/usr/lib/liblapack.so;/usr/lib/libblas.so")
